summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/orbsvcs/Notify/Event.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/orbsvcs/Notify/Event.h')
-rw-r--r--TAO/orbsvcs/orbsvcs/Notify/Event.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/TAO/orbsvcs/orbsvcs/Notify/Event.h b/TAO/orbsvcs/orbsvcs/Notify/Event.h
index c232eb8bafb..12c1b6e111a 100644
--- a/TAO/orbsvcs/orbsvcs/Notify/Event.h
+++ b/TAO/orbsvcs/orbsvcs/Notify/Event.h
@@ -9,8 +9,8 @@
*
*/
-#ifndef TAO_NS_EVENT_H
-#define TAO_NS_EVENT_H
+#ifndef TAO_Notify_EVENT_H
+#define TAO_Notify_EVENT_H
#include "ace/pre.h"
#include "notify_export.h"
@@ -27,26 +27,26 @@
#include "Property.h"
#include "Property_T.h"
-class TAO_NS_Consumer;
-class TAO_NS_EventType;
+class TAO_Notify_Consumer;
+class TAO_Notify_EventType;
/**
- * @class TAO_NS_Event
+ * @class TAO_Notify_Event
*
* @brief Base class abstraction for Events flowing through the EventChannel.
*
*/
-class TAO_Notify_Export TAO_NS_Event : private ACE_Copy_Disabled
+class TAO_Notify_Export TAO_Notify_Event : private ACE_Copy_Disabled
{
public:
/// Constuctor
- TAO_NS_Event (void);
+ TAO_Notify_Event (void);
/// Destructor
- virtual ~TAO_NS_Event ();
+ virtual ~TAO_Notify_Event ();
/// Copy the event.
- virtual TAO_NS_Event* copy (ACE_ENV_SINGLE_ARG_DECL) const = 0;
+ virtual TAO_Notify_Event* copy (ACE_ENV_SINGLE_ARG_DECL) const = 0;
/// Translate Any to Structured
static void translate (const CORBA::Any& any, CosNotification::StructuredEvent& notification);
@@ -55,7 +55,7 @@ public:
static void translate (const CosNotification::StructuredEvent& notification, CORBA::Any& any);
/// Get the event type.
- virtual const TAO_NS_EventType& type (void) const = 0;
+ virtual const TAO_Notify_EventType& type (void) const = 0;
/// Returns true if the filter matches.
virtual CORBA::Boolean do_match (CosNotifyFilter::Filter_ptr filter ACE_ENV_ARG_DECL) const = 0;
@@ -64,7 +64,7 @@ public:
virtual void convert (CosNotification::StructuredEvent& notification) const = 0;
/// Push event to consumer
- virtual void push (TAO_NS_Consumer* consumer ACE_ENV_ARG_DECL) const = 0;
+ virtual void push (TAO_Notify_Consumer* consumer ACE_ENV_ARG_DECL) const = 0;
/// Push event to the Event_Forwarder interface
virtual void push (Event_Forwarder::StructuredProxyPushSupplier_ptr forwarder ACE_ENV_ARG_DECL) const = 0;
@@ -80,61 +80,61 @@ public:
///= Accessors
/// Priority
- const TAO_NS_Property_Short& priority (void) const;
+ const TAO_Notify_Property_Short& priority (void) const;
/// Timeout
- const TAO_NS_Property_Time& timeout (void) const;
+ const TAO_Notify_Property_Time& timeout (void) const;
protected:
/// = QoS properties
/// Priority.
- TAO_NS_Property_Short priority_;
+ TAO_Notify_Property_Short priority_;
/// Timeout.
- TAO_NS_Property_Time timeout_;
+ TAO_Notify_Property_Time timeout_;
};
-typedef ACE_Refcounted_Auto_Ptr<const TAO_NS_Event, TAO_SYNCH_MUTEX> TAO_NS_Event_var_Base;
+typedef ACE_Refcounted_Auto_Ptr<const TAO_Notify_Event, TAO_SYNCH_MUTEX> TAO_Notify_Event_var_Base;
/**
- * @class TAO_NS_Event_var
+ * @class TAO_Notify_Event_var
*
* @brief A Non-Copy version of the ACE_Refcounted_Auto_Ptr that hides the constructors.
*
*/
-class TAO_NS_Event_var : public TAO_NS_Event_var_Base
+class TAO_Notify_Event_var : public TAO_Notify_Event_var_Base
{
public:
/// Default Constructor
- TAO_NS_Event_var (void);
+ TAO_Notify_Event_var (void);
protected:
/// Constructor
- TAO_NS_Event_var (TAO_NS_Event* event);
+ TAO_Notify_Event_var (TAO_Notify_Event* event);
};
/**
- * @class TAO_NS_Event
+ * @class TAO_Notify_Event
*
* @brief A version of the ACE_Refcounted_Auto_Ptr that allows construction from a TAO_NS_Event
*
*/
-class TAO_NS_Event_Copy_var : public TAO_NS_Event_var
+class TAO_Notify_Event_Copy_var : public TAO_Notify_Event_var
{
public:
/// Default Constructor
- TAO_NS_Event_Copy_var (void);
+ TAO_Notify_Event_Copy_var (void);
/// Constructor
- TAO_NS_Event_Copy_var (TAO_NS_Event* event);
+ TAO_Notify_Event_Copy_var (TAO_Notify_Event* event);
};
-typedef ACE_Unbounded_Queue<TAO_NS_Event_var> TAO_NS_Event_Collection;
+typedef ACE_Unbounded_Queue<TAO_Notify_Event_var> TAO_Notify_Event_Collection;
#if defined (__ACE_INLINE__)
#include "Event.inl"
#endif /* __ACE_INLINE__ */
#include "ace/post.h"
-#endif /* TAO_NS_EVENT_H */
+#endif /* TAO_Notify_EVENT_H */
@@ -80,61 +80,61 @@ public:
*
- * @brief A version of the ACE_Refcounted_Auto_Ptr that allows construction from a TAO_NS_Event
+ * @brief A version of the ACE_Refcounted_Auto_Ptr that allows construction from a TAO_Notify_Event
*
*/